@@ -3,6 +3,7 @@ import os
 import click
 import pygments
 import cls_client
+import barrel
 
 from .core import Combine
 from .dev import Watcher, Server
@@ -16,15 +17,11 @@ cls_client.set_version(__version__)
 cls_client.set_noninteractive_tracking_enabled(True)
 
 
-@click.group(invoke_without_command=True)
-@click.option("--version", "-v", is_flag=True, help="Show version and exit.")
+@click.group()
+@click.version_option(__version__)
 @click.pass_context
-def cli(ctx, version):
-    if not ctx.invoked_subcommand:
-        if version:
-            click.echo(__version__)
-        else:
-            click.echo(ctx.get_help())
+def cli(ctx):
+    pass
 
 
 @cli.command()
@@ -37,6 +34,7 @@ def cli(ctx, version):
     include_env=["NETLIFY", "CIRCLECI", "TRAVIS", "GITLAB_CI", "GITHUB_ACTIONS", "CI"],
 )
 def build(ctx, check, env, var):
+    """Build the site (typically during deployment)"""
     variables = dict(x.split("=") for x in var)
     config_path = os.path.abspath("combine.yml")
     combine = Combine(config_path=config_path, env=env, variables=variables)
@@ -62,8 +60,10 @@ def build(ctx, check, env, var):
 @cli.command()
 @click.option("--port", type=int, default=8000)
 @click.pass_context
-@cls_client.track_command()
 def work(ctx, port):
+    """Start a local server to build the site while you work"""
+    cls_client.track_event(slug="work", type="command", metadata={}, dispatch=True)
+
     config_path = os.path.abspath("combine.yml")
     combine = Combine(
         config_path=config_path,
@@ -102,6 +102,7 @@ def work(ctx, port):
 @cli.group()
 @click.pass_context
 def utils(ctx):
+    """Utility commands"""
     pass
 
 
@@ -122,5 +123,11 @@ def highlight_css(ctx, style):
         click.echo(f".highlight {line}")
 
 
+@cli.command()
+def update():
+    """Update your version of combine"""
+    barrel.update("combine")
+
+
 if __name__ == "__main__":
     cli()
